@@ -10,7 +10,7 @@
 
 #include "bttransferfactory.h"
 
-// header inclusion order is crucial because of signal emit clashes
+// header inclusion order is crucial because of signal Q_EMIT clashes
 #include "bttransfer.h"
 #include "btdatasource.h"
 #include "bttransferhandler.h"
@@ -49,17 +49,17 @@ Transfer * BTTransferFactory::createTransfer(const QUrl &srcUrl, const QUrl &des
     {
         return new BTTransfer(parent, this, scheduler, srcUrl, destUrl, e);
     }
-    return 0;
+    return nullptr;
 }
 
 TransferHandler * BTTransferFactory::createTransferHandler(Transfer * transfer, Scheduler * scheduler)
 {
-    BTTransfer * bttransfer = qobject_cast<BTTransfer *>(transfer);
+    auto * bttransfer = qobject_cast<BTTransfer *>(transfer);
 
     if (!bttransfer)
     {
         qCCritical(KGET_DEBUG) << "WARNING! passing a non-BTTransfer pointer!!";
-        return 0;
+        return nullptr;
     }
 
     return new BTTransferHandler(bttransfer, scheduler);
@@ -67,25 +67,25 @@ TransferHandler * BTTransferFactory::createTransferHandler(Transfer * transfer,
 
 QWidget * BTTransferFactory::createDetailsWidget( TransferHandler * transfer )
 {
-    BTTransferHandler * bttransfer = static_cast<BTTransferHandler *>(transfer);
+    auto * bttransfer = static_cast<BTTransferHandler *>(transfer);
 
     return new BTDetailsWidget(bttransfer);
 }
 
 const QList<QAction *> BTTransferFactory::actions(TransferHandler *handler)
 {
-     BTTransferHandler * bttransfer = static_cast<BTTransferHandler *>(handler);
+     auto * bttransfer = static_cast<BTTransferHandler *>(handler);
 
      QList<QAction *> actions;
      if (bttransfer && bttransfer->torrentControl())
      {
-         QAction *openAdvancedDetailsAction = new QAction(QIcon::fromTheme("document-open"), i18n("&Advanced Details"), this);
+         auto *openAdvancedDetailsAction = new QAction(QIcon::fromTheme("document-open"), i18n("&Advanced Details"), this);
  
          connect(openAdvancedDetailsAction, &QAction::triggered, bttransfer, &BTTransferHandler::createAdvancedDetails);
  
          actions.append(openAdvancedDetailsAction);
 
-         QAction *openScanDlg = new QAction(QIcon::fromTheme("document-open"), i18n("&Scan Files"), this);
+         auto *openScanDlg = new QAction(QIcon::fromTheme("document-open"), i18n("&Scan Files"), this);
  
          connect(openScanDlg, &QAction::triggered, bttransfer, &BTTransferHandler::createScanDlg);
  
@@ -105,7 +105,7 @@ TransferDataSource * BTTransferFactory::createTransferDataSource(const QUrl &src
     Q_UNUSED(parent)
     /*if (srcUrl.fileName().endsWith(".torrent"))
         return new BTDataSource();*/
-    return 0;
+    return nullptr;
 }
 
 bool BTTransferFactory::isSupported(const QUrl &url) const
