@@ -24,7 +24,7 @@
 KGET_EXPORT_PLUGIN_CONFIG(DlgMmsSettings)
 
 DlgMmsSettings::DlgMmsSettings(QWidget *parent, const QVariantList &args)
-    : KCModule(/*KGetFactory::componentData(), */parent, args)
+    : KCModule(parent, args)
 {
     ui.setupUi(this);
     connect(ui.numThreadSpinBox, SIGNAL(valueChanged(int)), SLOT(changed()));
