@@ -17,7 +17,7 @@
 KGET_EXPORT_PLUGIN_CONFIG(DlgSettingsWidget)
 
 DlgSettingsWidget::DlgSettingsWidget(QWidget *parent, const QVariantList &args)
-    : KCModule(/*KGetFactory::componentData(), */parent, args)
+    : KCModule(parent, args)
 {
     ui.setupUi(this);
 
